Crate icmd

Crate icmd 

Modules

canvas
Module for canvas drawing operations.
console
Module for the ICmd Console.
event
Module handling events and listeners.
measure
Module for measurement utilities used in layout calculations.
node
Module providing the core Node abstraction and concrete UI components.
style
Terminal styling and border patterns for ICmd. This module provides traits and implementations for applying ANSI-based styles to terminal text as well as defining reusable border patterns.
utils

Macros

node_impl_traits
Macro to implement standard traits for a node type.
tstr
A macro to create a new TString from a string literal or format string.