Module event

Module event 

Module handling events and listeners.

Structs

KeyPressEvent
Represents a keyboard press event.
KeyboardPress
A listener for keyboard press events.
MouseClick
A listener for mouse click events.
MouseEvent
Represents a mouse event.
NodeUpdate
A NodeUpdate listener that updates a node based on a callback.

Enums

Button
Enum representing mouse buttons.
Key
Enum representing key inputs.
MouseState
Enum representing mouse states.

Traits

Event
Trait for representing an event that can be converted from a RawEvent.
Listener
Listener trait for handling events. Returns a boolean indicating if event propagation should continue.